Index: /trunk/src/geometry_calib.m
===================================================================
--- /trunk/src/geometry_calib.m	(revision 540)
+++ /trunk/src/geometry_calib.m	(revision 541)
@@ -139,9 +139,9 @@
 if ~isempty(huvmat)
     handles=guidata(huvmat);
-    hobject=findobj(handles.axes3,'tag','calib_points');
+    hobject=findobj(handles.PlotAxes,'tag','calib_points');
     if ~isempty(hobject)
         delete(hobject)
     end
-    hobject=findobj(handles.axes3,'tag','calib_marker');
+    hobject=findobj(handles.PlotAxes,'tag','calib_marker');
     if ~isempty(hobject)
         delete(hobject)
@@ -287,9 +287,9 @@
     
     %display image with new calibration in the currently opened uvmat interface
-    hhh=findobj(hhuvmat.axes3,'Tag','calib_marker');% delete calib points and markers
+    hhh=findobj(hhuvmat.PlotAxes,'Tag','calib_marker');% delete calib points and markers
     if ~isempty(hhh)
         delete(hhh);      
     end
-    hhh=findobj(hhuvmat.axes3,'Tag','calib_points');
+    hhh=findobj(hhuvmat.PlotAxes,'Tag','calib_points');
     if ~isempty(hhh)
         delete(hhh);
@@ -998,5 +998,5 @@
     end
 end
-%axes(hhuvmat.axes3)
+
 set(0,'CurrentFigure',huvmat)
 set(huvmat,'CurrentAxes',hhuvmat.PlotAxes)
Index: /trunk/src/uvmat.m
===================================================================
--- /trunk/src/uvmat.m	(revision 540)
+++ /trunk/src/uvmat.m	(revision 541)
@@ -1355,6 +1355,7 @@
         choice_value=get(handles.transform_fct,'Value');
         transform_name=menu_transform{choice_value};%name of the transform fct  given by the menu 'transform_fct'
-        transform_list=get(handles.transform_fct,'UserData');
-        transform=transform_list{choice_value};
+%         transform_list=get(handles.transform_fct,'UserData');
+%         transform=transform_list{choice_value};
+        transform=get(handles.path_transform,'UserData');
         if  ~isequal(transform_name,'') && ~isequal(transform_name,'px')
             if isfield(UvData,'XmlData') && isfield(UvData.XmlData{1},'GeometryCalib')%use geometry calib recorded from the ImaDoc xml file as first priority
@@ -3558,9 +3559,9 @@
 end
 
-set(handles.CheckFixLimits,'Value',0)
-set(handles.CheckFixLimits,'BackgroundColor',[0.7 0.7 0.7])
 
 %% delete drawn objects if the output CooordUnit is different from the previous one
 if ~strcmp(CoordUnit,CoordUnitPrev)
+    set(handles.CheckFixLimits,'Value',0)
+set(handles.CheckFixLimits,'BackgroundColor',[0.7 0.7 0.7])
     hother=findobj('Tag','proj_object');%find all the proj objects
     for iobj=1:length(hother)

Index: /trunk/src/mouse_down.m
===================================================================
--- /trunk/src/mouse_down.m	(revision 540)
+++ /trunk/src/mouse_down.m	(revision 541)
@@ -377,6 +377,6 @@
 end
 
-%% create calibration points if the GUI geometry_calib is opened, if the main axes axes3 of uvmat has ben selected
-if ~test_zoom && test_cal && ~isempty(haxes) && strcmp(get(haxes,'tag'),'axes3') 
+%% create calibration points if the GUI geometry_calib is opened, if the main axes PlotAxes of uvmat has ben selected
+if ~test_zoom && test_cal && ~isempty(haxes) && strcmp(get(haxes,'tag'),'PlotAxes') 
     h_geometry_calib=findobj(allchild(0),'Name','geometry_calib'); %find the geomterty_calib GUI
     hh_geometry_calib=guidata(h_geometry_calib);